SystemOrganization addCategory: 'OrbeonBPMRuntime_Tests'!

TestCase subclass: #BpmCodeAnalyzerTest
	instanceVariableNames: 'analyzer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime_Tests'!

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:10'!
setUp

	analyzer := BpmCodeAnalyzer new.! !

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:19'!
tearDown

	analyzer := nil! !

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:25'!
testClassMessageAndForbiddenMesage

	analyzer blockCode: '[:proc | MyClass resetAll. proc class removeAll]'.

	analyzer analyze.

	self assert: (analyzer codeWarnings size = 2).! !

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:32'!
testMoreThanOneArgument

	analyzer blockCode: '[:form :proc | ]'.

	analyzer analyze.

	self assert: (analyzer codeWarnings size = 1).! !

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:22'!
testOk

	analyzer blockCode: '[:proc | proc taskFiveDate < (Date fromString: ''12/12/2015'') 
and: [proc taskSixTime < (Time fromString: ''14:00'')]]'.

	analyzer analyze.

	self assert: (analyzer codeWarnings size = 0).! !

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:39'!
testValidMessageToArgument

	analyzer blockCode: '[:proc | proc currentActivities removeAll]'.

	analyzer analyze.

	self assert: (analyzer codeWarnings size = 1).! !

!BpmCodeAnalyzerTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 11:33'!
testZeroArgument

	analyzer blockCode: '[ ]'.

	analyzer analyze.

	self assert: (analyzer codeWarnings size = 1).! !

TestCase subclass: #BpmProcessExecutionTest
	instanceVariableNames: 'procInstance users roles'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime_Tests'!

BpmProcessExecutionTest subclass: #AllGatewaysProcessExecutionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime_Tests'!

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 13:54'!
createProcessDefinition
	| xpdlReader processGenerator |

	xpdlReader := XPDLProcessDefinitionTemplate xpdlReaderForAllGatewaysProcess.

	processGenerator := BpmProcessGenerator on: xpdlReader xpdlPackages.
	processGenerator mapProcess: 'all gateways' toApplication: (self getApplicationManagerClass getAnyApplicationNamed: 'ue');
		generateAllProcess.

	processGenerator processes do: [:each | each addToCache].

	^processGenerator getProcessDefinitionNamed: 'all gateways' ifNone: [self assert: false].! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 13:59'!
formInstance_task1

	^self createFormInstance: #form_task1 definitionNamed: 'task-1' app: 'ue'! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 14:06'!
formInstance_task2

	^self createFormInstance: #form_task2 definitionNamed: 'task-2' app: 'ue'! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 14:07'!
formInstance_task3

	^self createFormInstance: #form_task3 definitionNamed: 'task-3' app: 'ue'! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 14:19'!
formInstance_task4

	^self createFormInstance: #form_task4 definitionNamed: 'task-4' app: 'ue'! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 14:08'!
formInstance_task5

	^self createFormInstance: #form_task5 definitionNamed: 'task-5' app: 'ue'! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 14:17'!
formInstance_task6

	^self createFormInstance: #form_task6 definitionNamed: 'task-6' app: 'ue'! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/08/2016 13:55'!
setUp
	| procDefinition |

	users := Dictionary new.

	procDefinition := BpmProcessDefinition getAllProcessesNamed: 'all gateways' in: 'ue'. "answer a collection with all versions"
	
	procDefinition := procDefinition ifEmpty: [self createProcessDefinition] ifNotEmpty: [:collection | collection last].

	users at: 'alberto' put: (BpmUser getUserNamed: 'alberto').

	procInstance := procDefinition createAndStartProcessInstance: (self getUserNamed: 'alberto').! !

!AllGatewaysProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/09/2016 10:30'!
testExecuteProcess_splitLastToEnd_bug
	| currentTask currentTask2 gateway endArtifact |

	self assert: (procInstance startEvent getDefinitionName = 'start all').
	"Step 1 - Form [task-1]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'alberto' withForm: self formInstance_task1.
	self assert: (currentTask getDefinitionName = 'task-1').
	"Step 2 - Gateway Evaluation"
	gateway := procInstance executedGateways asOrderedCollection last.
	self assert: (gateway getDefinitionName = 'split 2 and 3').
	"Step 3 - Form [task-2] and [task-3]"
	currentTask :=  procInstance currentActivities first.
	currentTask2 :=  procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'alberto' withForm: self formInstance_task2.
	self assert: (currentTask getDefinitionName = 'task-2').
	self processTask: currentTask2 withUserNamed: 'alberto' withForm: self formInstance_task3.
	self assert: (currentTask2 getDefinitionName = 'task-3').
	"Step 4 - TWO Gateway Evaluations"
	gateway := procInstance executedGateways asOrderedCollection second.
	self assert: (gateway getDefinitionName = 'merge 2 and 3').
	gateway := procInstance executedGateways asOrderedCollection last.
	self assert: (gateway getDefinitionName = 'task 4 or 5').
	"Step 5 - Form [task-5]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'alberto' withForm: self formInstance_task5.
	self assert: (currentTask getDefinitionName = 'task-5').
	"Step 6 - Form [task-6]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'alberto' withForm: self formInstance_task6.
	self assert: (currentTask getDefinitionName = 'task-6').
	"Step 7 - Process End"
	endArtifact := procInstance endEvents asOrderedCollection last.
	self assert: ((endArtifact getDefinitionName = 'end all') and: [endArtifact isEndEvent]).! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 03/31/2016 16:34'!
createFormInstance: xmlMethodName definitionNamed: definitionName app: app
	"The receiver create anOrbeonFormInstance of form definition named <definitionName> of Orbeon Applicaiton named <app> using the method <xmlMethodName> to get the XML string of the form "
	| application definition formInstance |

	application := self getApplicationManagerClass getAnyApplicationNamed: app.
	definition := application definitionNamed: definitionName.

	formInstance := 
		(OrbeonFormInstance app: app form: definitionName id: UUID new asString)
			definition: definition;
			xmlString: (OrbeonFormInstanceTemplate perform: xmlMethodName);
			processXML;
			yourself.

	procInstance definition updateFieldsOf: formInstance. "create AppFieldValue for the process definition"

	^formInstance! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 03/29/2016 14:31'!
getAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance
	"The receiver get the assignment for <aBpmTaskInstance> in the process <aBpmProcessInstance>. 
	1- Get the matrix (BpmTasksHolderMatrix) based on the application that the process <aBpmProcessInstance> belong.
	2- Get the assignment for the roles of the task <aBpmTaskInstance>"

	^self getAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance ifNone: [self assert: false]! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 03/29/2016 14:30'!
getAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance ifNone: aBlock
	"The receiver get the assignment for <aBpmTaskInstance> in the process <aBpmProcessInstance>. 
	1- Get the matrix (BpmTasksHolderMatrix) based on the application that the process <aBpmProcessInstance> belong.
	2- Get the assignment for the roles of the task <aBpmTaskInstance>"

	^(self getProcessMatrixFor: aBpmProcessInstance) getAssignmentFor: aBpmTaskInstance ifNone: aBlock! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 03/29/2016 14:44'!
getFinishedAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance
	"The receiver get the assignment for <aBpmTaskInstance> in the process <aBpmProcessInstance>. 
	1- Get the matrix (BpmTasksHolderMatrix) based on the application that the process <aBpmProcessInstance> belong.
	2- Get the assignment for the roles of the task <aBpmTaskInstance>"

	^(self getFinishedProcessMatrixFor: aBpmProcessInstance) getAssignmentFor: aBpmTaskInstance ifNone: [self assert: false]! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 03/29/2016 14:43'!
getFinishedAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance ifNone: aBlock
	"The receiver get the assignment for <aBpmTaskInstance> in the process <aBpmProcessInstance>. 
	1- Get the matrix (BpmTasksHolderMatrix) based on the application that the process <aBpmProcessInstance> belong.
	2- Get the assignment for the roles of the task <aBpmTaskInstance>"

	^(self getFinishedProcessMatrixFor: aBpmProcessInstance) getAssignmentFor: aBpmTaskInstance ifNone: aBlock! !

!BpmProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/29/2016 14:41'!
getFinishedProcessMatrix

	^self getFinishedProcessMatrixFor: procInstance! !

!BpmProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/29/2016 14:41'!
getFinishedProcessMatrixFor: aBpmProcessInstance

	^aBpmProcessInstance getFinishedProcessMatrix! !

!BpmProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 12/07/2015 06:51'!
getProcessMatrix

	^self getProcessMatrixFor: procInstance! !

!BpmProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 12/07/2015 06:51'!
getProcessMatrixFor: aBpmProcessInstance

	^aBpmProcessInstance getProcessMatrix! !

!BpmProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/27/2016 16:13'!
getUserNamed: aString

	^users at: aString ifAbsent: [self assert: false]! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 12/07/2015 06:59'!
processTask: aBpmTaskInstance withUserNamed: aString withForm: anOrbeonFormInstance
	"The receiver simulate the task processing of <aBpmTaskInstance> by user named <aString> in the process <aBpmProcessInstance>. 
	The task has the form instance <anOrbeonFormInstance>.
	1- Get the actual assignment of the task <aBpmTaskAssignment> from the tasks matrix.
	2- The user take the assignment.
	3- Associate the task and the form instance.
	4- The user finalize the assigment"

	^self processTask: aBpmTaskInstance withUserNamed: aString withForm: anOrbeonFormInstance on: procInstance! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 04/01/2016 14:31'!
processTask: aBpmTaskInstance withUserNamed: aString withForm: anOrbeonFormInstance on: aBpmProcessInstance
	"The receiver simulate the task processing of <aBpmTaskInstance> by user named <aString> in the process <aBpmProcessInstance>. 
	The task has the form instance <anOrbeonFormInstance>.
	1- Get the actual assignment of the task <aBpmTaskAssignment> from the tasks matrix.
	2- The user take the assignment.
	3- Associate the task and the form instance.
	4- The user finalize the assigment"
	| assignment |

	assignment := self takeTask: aBpmTaskInstance forUserNamed: aString withForm: anOrbeonFormInstance on: aBpmProcessInstance.

	(self getAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance ifNone: [nil]) 
	ifNotNil: [self assert: false]. "the assignment has been already taken --> this must answer nil"

	(self getUserNamed: aString) finalizeAssignment: assignment.

	"the assignment has been finished (by the role or by all performers) --> this must be in the finished matrix"
	(aBpmTaskInstance isFinishedByPerformers)
	ifTrue: [(self getFinishedAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance ifNone: [nil]) ifNil: [self assert: false]]! !

!BpmProcessExecutionTest methodsFor: 'Accessing' stamp: 'BrunoBB 12/07/2015 06:51'!
procInstance
	^procInstance! !

!BpmProcessExecutionTest methodsFor: 'Updating' stamp: 'BrunoBB 12/07/2015 06:51'!
procInstance: newValue
	procInstance := newValue! !

!BpmProcessExecutionTest methodsFor: 'execution simulation' stamp: 'BrunoBB 03/31/2016 17:05'!
takeTask: aBpmTaskInstance forUserNamed: aString withForm: anOrbeonFormInstance on: aBpmProcessInstance
	"The receiver take the task <aBpmTaskInstance> for user named <aString> in the process <aBpmProcessInstance>. 
	The task has the form instance <anOrbeonFormInstance>.
	1- Get the actual assignment of the task <aBpmTaskAssignment> from the tasks matrix.
	2- The user take the assignment.
	3- Associate the task and the form instance.
	4- Answer the assignment <aBpmTaskAssignment>"
	| assignment |

	assignment := self getAssignmentFor: aBpmTaskInstance on: aBpmProcessInstance.

	(self getUserNamed: aString) take: assignment.

	aBpmTaskInstance externalObject: anOrbeonFormInstance.
	anOrbeonFormInstance assignment: assignment.

	^assignment! !

BpmProcessExecutionTest subclass: #DataEntryMultiRoleProcessExecutionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime_Tests'!

!DataEntryMultiRoleProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/01/2016 12:35'!
createProcessDefinition
	| xpdlReader processGenerator |

	xpdlReader := XPDLProcessDefinitionTemplate xpdlReaderForDataEntryProcess.

	processGenerator := BpmProcessGenerator on: xpdlReader xpdlPackages.
	processGenerator mapProcess: 'multi-role' toApplication: (self getApplicationManagerClass getAnyApplicationNamed: 'ue');
		generateAllProcess.

	processGenerator processes do: [:each | each addToCache].

	^processGenerator getProcessDefinitionNamed: 'multi-role' ifNone: [self assert: false].! !

!DataEntryMultiRoleProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/01/2016 14:56'!
formInstance_data_approved

	^self createFormInstance: #form_data_approved_1 definitionNamed: 'data-approved' app: 'ue'! !

!DataEntryMultiRoleProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/01/2016 13:18'!
formInstance_data_entry

	^self createFormInstance: #form_data_entry_1 definitionNamed: 'data-entry' app: 'ue'! !

!DataEntryMultiRoleProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/01/2016 13:00'!
setUp
	| procDefinition |

	users := Dictionary new.

	procDefinition := BpmProcessDefinition getAllProcessesNamed: 'multi-role' in: 'ue'. "answer a collection with all versions"
	
	procDefinition := procDefinition ifEmpty: [self createProcessDefinition] ifNotEmpty: [:collection | collection last].

	users at: 'alberto' put: (BpmUser getUserNamed: 'alberto'). "data-entry-1"
	users at: 'juan' put: (BpmUser getUserNamed: 'juan'). "data-entry-2"
	users at: 'mario' put: (BpmUser getUserNamed: 'mario')."data-entry-3"
	users at: 'bruno' put: (BpmUser getUserNamed: 'bruno')."approver"

	procInstance := procDefinition createAndStartProcessInstance: (self getUserNamed: 'alberto').! !

!DataEntryMultiRoleProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 04/12/2016 13:47'!
testExecuteProcess_data_entry_approved
	| currentTask endArtifact |

	self assert: (procInstance startEvent getDefinitionName = 'start multi role').
	"Step 1.1 - Form [data-entry]" "Performer 1"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'alberto' withForm: self formInstance_data_entry.
	self assert: ((currentTask getCurrentRoleIfNone: [self assert: false]) name = 'data-entry-1').
	self assert: ((currentTask rolesWhoWorked last) name = 'data-entry-1').
	self assert: (currentTask getDefinitionName = 'data-entry').
	"Step 1.2 - Form [data-entry]" "Performer 2"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'juan' withForm: self formInstance_data_entry.
	self assert: ((currentTask getCurrentRoleIfNone: [self assert: false]) name = 'data-entry-2').
	self assert: ((currentTask rolesWhoWorked last) name = 'data-entry-2').
	self assert: (currentTask getDefinitionName = 'data-entry').
	"Step 1.3 - Form [data-entry]" "Performer 3"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'mario' withForm: self formInstance_data_entry.
	self assert: ((currentTask getCurrentRoleIfNone: [self assert: false]) name = 'data-entry-3').
	self assert: ((currentTask rolesWhoWorked last) name = 'data-entry-3').
	self assert: (currentTask getDefinitionName = 'data-entry').
	"Step 2 - Form [data-approved]" 
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'bruno' withForm: self formInstance_data_approved.
	self assert: (currentTask getDefinitionName = 'data-approved').
	endArtifact := procInstance endEvents asOrderedCollection last.
	self assert: ((endArtifact getDefinitionName = 'end multi role') and: [endArtifact isEndEvent]).! !

BpmProcessExecutionTest subclass: #SimpleRegistrationProcessExecutionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime_Tests'!

!SimpleRegistrationProcessExecutionTest commentStamp: '' prior: 0!
This is an Anonymous Process. The process is started by an Anonymous User.!

!SimpleRegistrationProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/31/2016 17:12'!
createProcessDefinition
	| xpdlReader processGenerator |

	xpdlReader := XPDLProcessDefinitionTemplate xpdlReaderForSimpleRegistrationProcess.

	processGenerator := BpmProcessGenerator on: xpdlReader xpdlPackages.
	processGenerator mapProcess: 'Simple Registration' toApplication: (self getApplicationManagerClass getAnyApplicationNamed: 'st');
		generateAllProcess.

	processGenerator processes do: [:each | each addToCache].

	"Associate the anonymous form with the ProcessDefinition"
	BpmProcessDefinition 
		registerAnonymousMappingForm: 'simple-registration' 
		in: 'st' 
		for: (BpmProcessDefinition getAllProcessesNamed: 'Simple Registration' in: 'st') last.

	^processGenerator getProcessDefinitionNamed: 'Simple Registration' ifNone: [self assert: false].! !

!SimpleRegistrationProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/31/2016 16:00'!
formInstance_registration_approval

	^self createFormInstance: #form_registration_approval_1 definitionNamed: 'registration-approval' app: 'st'! !

!SimpleRegistrationProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/31/2016 15:56'!
formInstance_simple_registration

	^self createFormInstance: #form_simple_registration_1 definitionNamed: 'simple-registration' app: 'st'! !

!SimpleRegistrationProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/31/2016 17:49'!
getAssignmentFor: aBpmTaskInstance

	^(BpmTaskAssignment newFor: procInstance task: aBpmTaskInstance in: self getFinishedMatrix)
		roleName: 'anonymous-user';
		yourself! !

!SimpleRegistrationProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/31/2016 17:31'!
getFinishedMatrix

	^BpmFinishedTasksMatrix cache at: 'st' ifAbsent: [self assert: false]! !

!SimpleRegistrationProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/31/2016 17:11'!
setUp
	| procDefinition |

	users := Dictionary new.

	procDefinition := BpmProcessDefinition getAllProcessesNamed: 'Simple Registration' in: 'st'. "answer a collection with all versions"
	
	procDefinition := procDefinition ifEmpty: [self createProcessDefinition] ifNotEmpty: [:collection | collection last].

	users at: 'alberto' put: (BpmUser getUserNamed: 'alberto').

	procInstance := procDefinition createAndStartProcessInstance: nil. "this process is started by an anonymous user"! !

!SimpleRegistrationProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/31/2016 17:50'!
testExecuteProcess_simpleRegistration_approved
	| currentTask endArtifact formInstance |

	self assert: (procInstance startEvent getDefinitionName = 'start-registration').
	"Step 1 - Form [simple-registration]" "THIS IS AN ANONYMOUS PROCESS"
	currentTask := procInstance currentActivities last.
	formInstance := self formInstance_simple_registration.
	currentTask externalObject: formInstance.
	formInstance assignment: (self getAssignmentFor: currentTask).
	currentTask finalize.

	self assert: (currentTask getDefinitionName = 'simple-registration').
	self assert: procInstance startEventIsAnonymous.
	procInstance generateNextTransitionsFrom: currentTask.
	"Step 2 - Form [registration-approval]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'alberto' withForm: self formInstance_registration_approval.
	self assert: (currentTask getDefinitionName = 'registration-approval').

	endArtifact := procInstance endEvents asOrderedCollection last.
	self assert: ((endArtifact getDefinitionName = 'end') and: [endArtifact isEndEvent]).! !

BpmProcessExecutionTest subclass: #VisaApplianceProcessExecutionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime_Tests'!

!VisaApplianceProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/29/2016 15:32'!
createProcessDefinition
	| xpdlReader processGenerator |

	xpdlReader := XPDLProcessDefinitionTemplate xpdlReaderForVisaProcess.

	processGenerator := BpmProcessGenerator on: xpdlReader xpdlPackages.
	processGenerator mapProcess: 'visa-appliance' toApplication: (self getApplicationManagerClass getAnyApplicationNamed: 'ue');
		mapProcess: 'home-office-check' toApplication: (self getApplicationManagerClass getAnyApplicationNamed: 'ue');
		mapProcess: 'check-financial-data' toApplication: (self getApplicationManagerClass getAnyApplicationNamed: 'ue');
		generateAllProcess.

	processGenerator processes do: [:each | each addToCache].

	^processGenerator getProcessDefinitionNamed: 'visa-appliance' ifNone: [self assert: false].! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:03'!
formInstance_analyze_appliance

	^self createFormInstance: #form_analyze_appliance_1 definitionNamed: 'analyze-appliance' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:08'!
formInstance_applicant_home_office_report

	^self createFormInstance: #form_applicant_home_office_report_1 definitionNamed: 'applicant-home-office-report' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:09'!
formInstance_check_accounts

	^self createFormInstance: #form_check_accounts_1 definitionNamed: 'check-accounts' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:08'!
formInstance_check_applicant_record

	^self createFormInstance: #form_check_applicant_record_1 definitionNamed: 'check-applicant-record' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:01'!
formInstance_check_basic_data

	^self createFormInstance: #form_check_basic_data_1 definitionNamed: 'check-basic-data' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:11'!
formInstance_check_debts

	^self createFormInstance: #form_check_debts_1 definitionNamed: 'check-debts' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:02'!
formInstance_check_previous_appliance

	^self createFormInstance: #form_check_previous_appliance_1 definitionNamed: 'check-previous-appliance' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:11'!
formInstance_check_properties

	^self createFormInstance: #form_check_properties_1 definitionNamed: 'check-properties' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 15:50'!
formInstance_citizen_appliance

	^self createFormInstance: #form_citizen_appliance_1 definitionNamed: 'citizen-appliance' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:06'!
formInstance_emit_visa

	^self createFormInstance: #form_emit_visa_1 definitionNamed: 'emit-visa' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'form instances' stamp: 'BrunoBB 03/26/2016 16:12'!
formInstance_financial_report

	^self createFormInstance: #form_financial_report_1 definitionNamed: 'financial-report' app: 'ue'! !

!VisaApplianceProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/27/2016 15:48'!
setUp
	| procDefinition |

	users := Dictionary new.

	procDefinition := BpmProcessDefinition getAllProcessesNamed: 'visa-appliance' in: 'ue'. "answer a collection with all versions"
	
	procDefinition := procDefinition ifEmpty: [self createProcessDefinition] ifNotEmpty: [:collection | collection last].

	users at: 'andrew vo' put: (BpmUser getUserNamed: 'andrew vo').
	users at: 'andrew vm' put: (BpmUser getUserNamed: 'andrew vm').
	users at: 'andrew vc' put: (BpmUser getUserNamed: 'andrew vc').
	users at: 'andrew fo' put: (BpmUser getUserNamed: 'andrew fo').
	users at: 'andrew po' put: (BpmUser getUserNamed: 'andrew po').
	users at: 'andrew do' put: (BpmUser getUserNamed: 'andrew do').

	procInstance := procDefinition createAndStartProcessInstance: (users at: 'andrew vo').! !

!VisaApplianceProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/26/2016 15:51'!
tearDown

	"procInstance definition removeProcessInstance: procInstance"! !

!VisaApplianceProcessExecutionTest methodsFor: 'other' stamp: 'BrunoBB 03/29/2016 13:56'!
testExecuteProcess_visaAccepted
	| currentTask gateway endArtifact subProcessL1 subProcessL2 |

	self assert: (procInstance startEvent getDefinitionName = 'visa apply start').
	"Step 1 - Form [citizen-appliance]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'andrew vo' withForm: self formInstance_citizen_appliance.
	self assert: (currentTask getDefinitionName = 'citizen-appliance').
	"Step 2 - Form [check-basic-data]"
	currentTask :=  procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'andrew vo' withForm: self formInstance_check_basic_data.
	self assert: (currentTask getDefinitionName = 'check-basic-data').
	"Step 3 - Gateway Evaluation"
	gateway := procInstance executedGateways asOrderedCollection last.
	self assert: (gateway getDefinitionName = 'accept basic data').
	"Step 4 - Form [check-previous-appliance]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'andrew vm' withForm: self formInstance_check_previous_appliance.
	self assert: (currentTask getDefinitionName = 'check-previous-appliance').
	"Sub Process Execution [home-office-check] starts here "
		subProcessL1 := procInstance subprocesses last.
		self assert: (procInstance includesSubProcess: subProcessL1).
		self assert:  subProcessL1 isSubProcess.
		self assert: (subProcessL1 startEvent getDefinitionName = 'start visa check').
		"Step 1 [subproc] - Form [check-applicant-record]"
		currentTask := subProcessL1 currentActivities last.
		self processTask: currentTask withUserNamed: 'andrew vc' withForm: self formInstance_check_applicant_record on: subProcessL1.
		self assert: (currentTask getDefinitionName = 'check-applicant-record').
		"Step 2 [subproc] - Form [applicant-home-office-report]"
		currentTask := subProcessL1 currentActivities last.
		self processTask: currentTask withUserNamed: 'andrew vc' withForm: self formInstance_applicant_home_office_report on: subProcessL1.
		self assert: (currentTask getDefinitionName = 'applicant-home-office-report').
		"Sub Process Execution [check-financial-data]"
			subProcessL2 := subProcessL1 subprocesses last.
			self assert: (subProcessL1 includesSubProcess: subProcessL2).
			self assert:  subProcessL2 isSubProcess.
			self assert: (subProcessL2 startEvent getDefinitionName = 'start financial check').
			"Step 1 [subproc] - Form [check-accounts]"
			currentTask := subProcessL2 currentActivities last.
			self processTask: currentTask withUserNamed: 'andrew fo' withForm: self formInstance_check_accounts on: subProcessL2.
			self assert: (currentTask getDefinitionName = 'check-accounts').
			"Step 2 [subproc] - Form [check-accounts]"
			currentTask := subProcessL2 currentActivities last.
			self processTask: currentTask withUserNamed: 'andrew po' withForm: self formInstance_check_properties on: subProcessL2.
			self assert: (currentTask getDefinitionName = 'check-properties').
			"Step 3 [subproc] - Form [check-accounts]"
			currentTask := subProcessL2 currentActivities last.
			self processTask: currentTask withUserNamed: 'andrew do' withForm: self formInstance_check_debts.
			self assert: (currentTask getDefinitionName = 'check-debts').
			"Step 3 [subproc] - Form [check-accounts]"
			currentTask := subProcessL2 currentActivities last.
			self processTask: currentTask withUserNamed: 'andrew fo' withForm: self formInstance_financial_report on: subProcessL2.
			self assert: (currentTask getDefinitionName = 'financial-report').
			"Sub Process [check-financial-data] ends and gives control to previous process"
		"Sub Process [check-applicant-record] ends and gives control to main process"
	"Top Process [visa-appliance] resume execution "
	"Step 5 - Form [analyze-appliance]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'andrew vm' withForm: self formInstance_analyze_appliance.
	self assert: (currentTask getDefinitionName = 'analyze-appliance').
	"Step 6 - Gateway Evaluation"
	gateway := procInstance executedGateways asOrderedCollection last.
	self assert: (gateway getDefinitionName = 'granted').
	"Step 7 - Form [emit-visa]"
	currentTask := procInstance currentActivities last.
	self processTask: currentTask withUserNamed: 'andrew vm' withForm: self formInstance_emit_visa.
	self assert: (currentTask getDefinitionName = 'emit-visa').

	endArtifact := procInstance endEvents asOrderedCollection last.
	self assert: ((endArtifact getDefinitionName = 'visa apply end') and: [endArtifact isEndEvent]).! !
